@@ -1,11 +1,16 @@
-__version__ = '0.1.5'
+__version__ = '0.2.4'
 import time
 import os
+try:
+  from colorama import colorama
+except:
+  os.system("pip install colorama")
+err = colorama.Fore.RED
+
 working = False
 class functions:
   #-----------------------------------------#   #--------------REPLACE LINE FUNCTION------------#  
-    def line_replace(self, file_name: str, lineindex: str, text: str, msg: bool):
-
+    def index_replace(self, file_name: str, lineindex: str, text: str, msg: bool):
       base = open(file_name, "r")
       ####
       lines = base.read()
@@ -36,28 +41,29 @@ class functions:
       
     #-----------------------------------------#   #--------------NEW LINE FUNCTION------------#  
           
-    def new_file(self, name: str, msg: bool):
+    def clear(self, name: str, msg: bool):
+      w = open(name, "w")
+      w.close()
+    
+    def new_file(self, name: str):
       try:
-        w = open(name, "w")
-        working=True
-        w.close()
-      except:
-        working=False
-  
-      if working == True:
-        if msg == True:
-          print("New File created")
-        elif msg == False:
-          pass
-      elif working == False:
-        raise FileExistsError("This file is an existing file. Please do not use this function if file already has been created. Sometimes this function can clear data stored.")
+        x = open(name, "x")
+      except FileExistsError:
+        print(err+"In line 50 of module JetDB,\nexcept FileExistsError:\n  raise CustomError(error)\n\nFileExistsError: [Errno 17] File exists, data might have been deleted: '{}'".format(name))
+        raise SystemExit(err+"> Program died due to incorrect values")
+      
+      
+      
 
     #-----------------------------------------#   #------------- ADD LINE FUNCTION ------------#
         
-    def add(self, file_name: str, text: str):
+    def add(self, file_name: str, text: str, msg: bool):
       f = open(file_name, "a")
       f.write(text+"\n")
-      print("Line added")
+      if msg == True:
+        print("Line added")
+      else:
+        pass
     #-----------------------------------------#   #--------------WAIT FUNCTION------------#  
       
     def wait(self, num: int):
@@ -79,7 +85,8 @@ class functions:
             w.close()
           except NameError:
             linename = lineindex
-            raise NameError(f"Incorrect Input. No matches: {linename}")
+            print(f"Incorrect Input. No matches: {linename}")
+            raise SystemExit(err+"> Program died due to incorrect values")
 
    #-----------------------------------------#   #--------------CHECK LINE/DATA FUNCTION------------# 
     def check_line(self, file_name: str, lineindex: str, linenum: int, string: bool):
@@ -103,4 +110,59 @@ class functions:
         print(txt)
       except NameError:
         pass
-          
\ No newline at end of file
+
+    def index(self, file_name: str, indextext: str):
+      global loc
+      loc = 0
+      global index
+      index = ""
+      base = open(file_name, "r")
+      ####
+      lines = base.read()
+      keys = lines.split("\n")
+      w = open("index.txt", "w")
+      w.close()
+      ####
+      for line in keys:
+        loc += 1
+        if line.startswith(str(indextext)):
+          try:
+            index += str(loc)
+            index += "\n"
+            with open("index.txt", "w") as f:
+              f.write(index)
+              f.close()
+            pass
+          except ValueError:
+            pass
+        else:
+          pass  
+    def listed_replace(self, file_name: str, listindex: int, text: str, msg: bool):
+      base = open(file_name, "r")
+      ####
+      lines = base.read()
+      keys = lines.split("\n")
+      ####
+      for line in keys:
+        try:
+          global loc
+          loc = listindex
+        except ValueError:
+          pass
+        try:
+          keys[loc] = str(keys[loc])
+          if keys[loc] != text:
+            keys[loc] = str(text)
+          with open(file_name, "w") as f:
+            f.write("\n".join(keys))
+            f.close()
+        except NameError:
+          linenum = lineindex
+          file = file_name
+          raise NameError(f'Input Incorrect. Input given was out of range; in {file} "{linenum}" is out of range')
+      if msg == True:
+        print("Line Replaced")
+      elif msg == False:
+        pass
+    def setup():
+      pass
\ No newline at end of file
